@@ -33,7 +33,11 @@ static const char URL[] = "https://www.ecb.europa.eu/stats/eurofxref/eurofxref-d
 
 static QString cacheLocation()
 {
+#ifndef Q_OS_ANDROID
     return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/libkunitconversion/currency.xml");
+#else
+    return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/libkunitconversion/currency.xml");
+#endif
 }
 
 class CurrencyCategoryPrivate : public UnitCategoryPrivate
@@ -431,7 +435,7 @@ UnitCategory Currency::makeCategory()
 
     d->addUnit(UnitPrivate::makeUnit(CurrencyCategory,
                        Hrk,
-                       qSNaN(),
+                       1.0/7.53450,
                        QStringLiteral("HRK"),
                        i18nc("currency name", "Croatian Kuna"),
                        i18nc("HRK Croatian Kuna - unit synonyms for matching user input", "kuna;kune") + QStringLiteral(";HRK;")
